import { Server as SocketIo } from 'socket.io';
import { SocketTools } from '../util/index.js';
import { ContainerPageSocket, SocketPageManager } from './socket-pages/index.js';
import { DockerAnalytics } from './docker/DockerAnalytics.js';
class SocketService {
    register(http) {
        SocketService.io = new SocketIo(http, {
            cors: {
                origin: '*',
            },
        });
        this.bindEvents();
        SocketPageManager.setSocketIo(SocketService.io);
        return SocketService.io;
    }
    getSocketIo() {
        return SocketService.io;
    }
    bindEvents() {
        SocketService.io.on('connection', (socket) => {
            const { page } = SocketTools.getQueryParams(socket);
            switch (page) {
                case 'dashboard':
                    socket.join('monitoring');
                    DockerAnalytics.start();
                    break;
                case 'container-management':
                    ContainerPageSocket.join(socket);
                    ContainerPageSocket.join(socket, 'monitoring');
                    ContainerPageSocket.bindEvents(socket);
                    DockerAnalytics.start();
                    break;
                default:
                    socket.join('default-page');
            }
        });
    }
    emit(options, params) {
        const { page, context } = options;
        if (context) {
            SocketPageManager.emitByContext(options, params);
        }
        else if (page) {
            SocketPageManager.emitByPage(options, params);
        }
    }
}
const instance = new SocketService();
export { instance as SocketService };
export default instance;
